==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkDataArray.java <==
// java wrapper for vtkDataArray object
//

package vtk;
import vtk.*;

public class vtkDataArray extends vtkAbstractArray
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long FastDownCast_2(vtkAbstractArray id0);
  public vtkDataArray FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_2(id0);

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IsNumeric_3();
  public int IsNumeric()
    { return IsNumeric_3(); }

  private native int GetElementComponentSize_4();
  public int GetElementComponentSize()
    { return GetElementComponentSize_4(); }

  private native void InsertTuple_5(int id0,int id1,vtkAbstractArray id2);
  public void InsertTuple(int id0,int id1,vtkAbstractArray id2)
    { InsertTuple_5(id0,id1,id2); }

  private native int InsertNextTuple_6(int id0,vtkAbstractArray id1);
  public int InsertNextTuple(int id0,vtkAbstractArray id1)
    { return InsertNextTuple_6(id0,id1); }

  private native void InsertTuples_7(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2);
  public void InsertTuples(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2)
    { InsertTuples_7(id0,id1,id2); }

  private native void InsertTuples_8(int id0,int id1,int id2,vtkAbstractArray id3);
  public void InsertTuples(int id0,int id1,int id2,vtkAbstractArray id3)
    { InsertTuples_8(id0,id1,id2,id3); }

  private native void GetTuples_9(vtkIdList id0,vtkAbstractArray id1);
  public void GetTuples(vtkIdList id0,vtkAbstractArray id1)
    { GetTuples_9(id0,id1); }

  private native void GetTuples_10(int id0,int id1,vtkAbstractArray id2);
  public void GetTuples(int id0,int id1,vtkAbstractArray id2)
    { GetTuples_10(id0,id1,id2); }

  private native void InterpolateTuple_11(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5);
  public void InterpolateTuple(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5)
    { InterpolateTuple_11(id0,id1,id2,id3,id4,id5); }

  private native double GetTuple1_12(int id0);
  public double GetTuple1(int id0)
    { return GetTuple1_12(id0); }

  private native double[] GetTuple2_13(int id0);
  public double[] GetTuple2(int id0)
    { return GetTuple2_13(id0); }

  private native double[] GetTuple3_14(int id0);
  public double[] GetTuple3(int id0)
    { return GetTuple3_14(id0); }

  private native double[] GetTuple4_15(int id0);
  public double[] GetTuple4(int id0)
    { return GetTuple4_15(id0); }

  private native double[] GetTuple6_16(int id0);
  public double[] GetTuple6(int id0)
    { return GetTuple6_16(id0); }

  private native double[] GetTuple9_17(int id0);
  public double[] GetTuple9(int id0)
    { return GetTuple9_17(id0); }

  private native void SetTuple_18(int id0,int id1,vtkAbstractArray id2);
  public void SetTuple(int id0,int id1,vtkAbstractArray id2)
    { SetTuple_18(id0,id1,id2); }

  private native void SetTuple1_19(int id0,double id1);
  public void SetTuple1(int id0,double id1)
    { SetTuple1_19(id0,id1); }

  private native void SetTuple2_20(int id0,double id1,double id2);
  public void SetTuple2(int id0,double id1,double id2)
    { SetTuple2_20(id0,id1,id2); }

  private native void SetTuple3_21(int id0,double id1,double id2,double id3);
  public void SetTuple3(int id0,double id1,double id2,double id3)
    { SetTuple3_21(id0,id1,id2,id3); }

  private native void SetTuple4_22(int id0,double id1,double id2,double id3,double id4);
  public void SetTuple4(int id0,double id1,double id2,double id3,double id4)
    { SetTuple4_22(id0,id1,id2,id3,id4); }

  private native void SetTuple6_23(int id0,double id1,double id2,double id3,double id4,double id5,double id6);
  public void SetTuple6(int id0,double id1,double id2,double id3,double id4,double id5,double id6)
    { SetTuple6_23(id0,id1,id2,id3,id4,id5,id6); }

  private native void SetTuple9_24(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9);
  public void SetTuple9(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9)
    { SetTuple9_24(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InsertTuple1_25(int id0,double id1);
  public void InsertTuple1(int id0,double id1)
    { InsertTuple1_25(id0,id1); }

  private native void InsertTuple2_26(int id0,double id1,double id2);
  public void InsertTuple2(int id0,double id1,double id2)
    { InsertTuple2_26(id0,id1,id2); }

  private native void InsertTuple3_27(int id0,double id1,double id2,double id3);
  public void InsertTuple3(int id0,double id1,double id2,double id3)
    { InsertTuple3_27(id0,id1,id2,id3); }

  private native void InsertTuple4_28(int id0,double id1,double id2,double id3,double id4);
  public void InsertTuple4(int id0,double id1,double id2,double id3,double id4)
    { InsertTuple4_28(id0,id1,id2,id3,id4); }

  private native void InsertTuple6_29(int id0,double id1,double id2,double id3,double id4,double id5,double id6);
  public void InsertTuple6(int id0,double id1,double id2,double id3,double id4,double id5,double id6)
    { InsertTuple6_29(id0,id1,id2,id3,id4,id5,id6); }

  private native void InsertTuple9_30(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9);
  public void InsertTuple9(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9)
    { InsertTuple9_30(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InsertNextTuple1_31(double id0);
  public void InsertNextTuple1(double id0)
    { InsertNextTuple1_31(id0); }

  private native void InsertNextTuple2_32(double id0,double id1);
  public void InsertNextTuple2(double id0,double id1)
    { InsertNextTuple2_32(id0,id1); }

  private native void InsertNextTuple3_33(double id0,double id1,double id2);
  public void InsertNextTuple3(double id0,double id1,double id2)
    { InsertNextTuple3_33(id0,id1,id2); }

  private native void InsertNextTuple4_34(double id0,double id1,double id2,double id3);
  public void InsertNextTuple4(double id0,double id1,double id2,double id3)
    { InsertNextTuple4_34(id0,id1,id2,id3); }

  private native void InsertNextTuple6_35(double id0,double id1,double id2,double id3,double id4,double id5);
  public void InsertNextTuple6(double id0,double id1,double id2,double id3,double id4,double id5)
    { InsertNextTuple6_35(id0,id1,id2,id3,id4,id5); }

  private native void InsertNextTuple9_36(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8);
  public void InsertNextTuple9(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8)
    { InsertNextTuple9_36(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void RemoveTuple_37(int id0);
  public void RemoveTuple(int id0)
    { RemoveTuple_37(id0); }

  private native void RemoveFirstTuple_38();
  public void RemoveFirstTuple()
    { RemoveFirstTuple_38(); }

  private native void RemoveLastTuple_39();
  public void RemoveLastTuple()
    { RemoveLastTuple_39(); }

  private native double GetComponent_40(int id0,int id1);
  public double GetComponent(int id0,int id1)
    { return GetComponent_40(id0,id1); }

  private native void SetComponent_41(int id0,int id1,double id2);
  public void SetComponent(int id0,int id1,double id2)
    { SetComponent_41(id0,id1,id2); }

  private native void InsertComponent_42(int id0,int id1,double id2);
  public void InsertComponent(int id0,int id1,double id2)
    { InsertComponent_42(id0,id1,id2); }

  private native void GetData_43(int id0,int id1,int id2,int id3,vtkDoubleArray id4);
  public void GetData(int id0,int id1,int id2,int id3,vtkDoubleArray id4)
    { GetData_43(id0,id1,id2,id3,id4); }

  private native void DeepCopy_44(vtkAbstractArray id0);
  public void DeepCopy(vtkAbstractArray id0)
    { DeepCopy_44(id0); }

  private native void DeepCopy_45(vtkDataArray id0);
  public void DeepCopy(vtkDataArray id0)
    { DeepCopy_45(id0); }

  private native void ShallowCopy_46(vtkDataArray id0);
  public void ShallowCopy(vtkDataArray id0)
    { ShallowCopy_46(id0); }

  private native void FillComponent_47(int id0,double id1);
  public void FillComponent(int id0,double id1)
    { FillComponent_47(id0,id1); }

  private native void Fill_48(double id0);
  public void Fill(double id0)
    { Fill_48(id0); }

  private native void CopyComponent_49(int id0,vtkDataArray id1,int id2);
  public void CopyComponent(int id0,vtkDataArray id1,int id2)
    { CopyComponent_49(id0,id1,id2); }

  private native int GetActualMemorySize_50();
  public int GetActualMemorySize()
    { return GetActualMemorySize_50(); }

  private native void CreateDefaultLookupTable_51();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_51(); }

  private native void SetLookupTable_52(vtkLookupTable id0);
  public void SetLookupTable(vtkLookupTable id0)
    { SetLookupTable_52(id0); }

  private native long GetLookupTable_53();
  public vtkLookupTable GetLookupTable() {
    long temp = GetLookupTable_53();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetRange_54(double id0[],int id1);
  public void GetRange(double id0[],int id1)
    { GetRange_54(id0,id1); }

  private native double[] GetRange_55(int id0);
  public double[] GetRange(int id0)
    { return GetRange_55(id0); }

  private native double[] GetRange_56();
  public double[] GetRange()
    { return GetRange_56(); }

  private native void GetRange_57(double id0[]);
  public void GetRange(double id0[])
    { GetRange_57(id0); }

  private native void GetFiniteRange_58(double id0[],int id1);
  public void GetFiniteRange(double id0[],int id1)
    { GetFiniteRange_58(id0,id1); }

  private native void GetFiniteRange_59(double id0[]);
  public void GetFiniteRange(double id0[])
    { GetFiniteRange_59(id0); }

  private native void GetDataTypeRange_60(double id0[]);
  public void GetDataTypeRange(double id0[])
    { GetDataTypeRange_60(id0); }

  private native double GetDataTypeMin_61();
  public double GetDataTypeMin()
    { return GetDataTypeMin_61(); }

  private native double GetDataTypeMax_62();
  public double GetDataTypeMax()
    { return GetDataTypeMax_62(); }

  private native void GetDataTypeRange_63(int id0,double id1[]);
  public void GetDataTypeRange(int id0,double id1[])
    { GetDataTypeRange_63(id0,id1); }

  private native double GetDataTypeMin_64(int id0);
  public double GetDataTypeMin(int id0)
    { return GetDataTypeMin_64(id0); }

  private native double GetDataTypeMax_65(int id0);
  public double GetDataTypeMax(int id0)
    { return GetDataTypeMax_65(id0); }

  private native double GetMaxNorm_66();
  public double GetMaxNorm()
    { return GetMaxNorm_66(); }

  private native long CreateDataArray_67(int id0);
  public vtkDataArray CreateDataArray(int id0) {
    long temp = CreateDataArray_67(id0);

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long COMPONENT_RANGE_68();
  public vtkInformationDoubleVectorKey COMPONENT_RANGE() {
    long temp = COMPONENT_RANGE_68();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long L2_NORM_RANGE_69();
  public vtkInformationDoubleVectorKey L2_NORM_RANGE() {
    long temp = L2_NORM_RANGE_69();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long L2_NORM_FINITE_RANGE_70();
  public vtkInformationDoubleVectorKey L2_NORM_FINITE_RANGE() {
    long temp = L2_NORM_FINITE_RANGE_70();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Modified_71();
  public void Modified()
    { Modified_71(); }

  private native long UNITS_LABEL_72();
  public vtkInformationStringKey UNITS_LABEL() {
    long temp = UNITS_LABEL_72();

    if (temp == 0) return null;
    return (vtkInformationStringKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CopyInformation_73(vtkInformation id0,int id1);
  public int CopyInformation(vtkInformation id0,int id1)
    { return CopyInformation_73(id0,id1); }

  private native int GetArrayType_74();
  public int GetArrayType()
    { return GetArrayType_74(); }

  public vtkDataArray() { super(); }

  public vtkDataArray(long id) { super(id); }

}

==> vtk-8.2.0-7-armv6h.pkg.tar.xz: vtk/vtkDataArray.java <==
// java wrapper for vtkDataArray object
//

package vtk;
import vtk.*;

public class vtkDataArray extends vtkAbstractArray
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long FastDownCast_2(vtkAbstractArray id0);
  public vtkDataArray FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_2(id0);

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IsNumeric_3();
  public int IsNumeric()
    { return IsNumeric_3(); }

  private native int GetElementComponentSize_4();
  public int GetElementComponentSize()
    { return GetElementComponentSize_4(); }

  private native void InsertTuple_5(int id0,int id1,vtkAbstractArray id2);
  public void InsertTuple(int id0,int id1,vtkAbstractArray id2)
    { InsertTuple_5(id0,id1,id2); }

  private native int InsertNextTuple_6(int id0,vtkAbstractArray id1);
  public int InsertNextTuple(int id0,vtkAbstractArray id1)
    { return InsertNextTuple_6(id0,id1); }

  private native void InsertTuples_7(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2);
  public void InsertTuples(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2)
    { InsertTuples_7(id0,id1,id2); }

  private native void InsertTuples_8(int id0,int id1,int id2,vtkAbstractArray id3);
  public void InsertTuples(int id0,int id1,int id2,vtkAbstractArray id3)
    { InsertTuples_8(id0,id1,id2,id3); }

  private native void GetTuples_9(vtkIdList id0,vtkAbstractArray id1);
  public void GetTuples(vtkIdList id0,vtkAbstractArray id1)
    { GetTuples_9(id0,id1); }

  private native void GetTuples_10(int id0,int id1,vtkAbstractArray id2);
  public void GetTuples(int id0,int id1,vtkAbstractArray id2)
    { GetTuples_10(id0,id1,id2); }

  private native void InterpolateTuple_11(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5);
  public void InterpolateTuple(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5)
    { InterpolateTuple_11(id0,id1,id2,id3,id4,id5); }

  private native double GetTuple1_12(int id0);
  public double GetTuple1(int id0)
    { return GetTuple1_12(id0); }

  private native double[] GetTuple2_13(int id0);
  public double[] GetTuple2(int id0)
    { return GetTuple2_13(id0); }

  private native double[] GetTuple3_14(int id0);
  public double[] GetTuple3(int id0)
    { return GetTuple3_14(id0); }

  private native double[] GetTuple4_15(int id0);
  public double[] GetTuple4(int id0)
    { return GetTuple4_15(id0); }

  private native double[] GetTuple6_16(int id0);
  public double[] GetTuple6(int id0)
    { return GetTuple6_16(id0); }

  private native double[] GetTuple9_17(int id0);
  public double[] GetTuple9(int id0)
    { return GetTuple9_17(id0); }

  private native void SetTuple_18(int id0,int id1,vtkAbstractArray id2);
  public void SetTuple(int id0,int id1,vtkAbstractArray id2)
    { SetTuple_18(id0,id1,id2); }

  private native void SetTuple1_19(int id0,double id1);
  public void SetTuple1(int id0,double id1)
    { SetTuple1_19(id0,id1); }

  private native void SetTuple2_20(int id0,double id1,double id2);
  public void SetTuple2(int id0,double id1,double id2)
    { SetTuple2_20(id0,id1,id2); }

  private native void SetTuple3_21(int id0,double id1,double id2,double id3);
  public void SetTuple3(int id0,double id1,double id2,double id3)
    { SetTuple3_21(id0,id1,id2,id3); }

  private native void SetTuple4_22(int id0,double id1,double id2,double id3,double id4);
  public void SetTuple4(int id0,double id1,double id2,double id3,double id4)
    { SetTuple4_22(id0,id1,id2,id3,id4); }

  private native void SetTuple6_23(int id0,double id1,double id2,double id3,double id4,double id5,double id6);
  public void SetTuple6(int id0,double id1,double id2,double id3,double id4,double id5,double id6)
    { SetTuple6_23(id0,id1,id2,id3,id4,id5,id6); }

  private native void SetTuple9_24(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9);
  public void SetTuple9(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9)
    { SetTuple9_24(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InsertTuple1_25(int id0,double id1);
  public void InsertTuple1(int id0,double id1)
    { InsertTuple1_25(id0,id1); }

  private native void InsertTuple2_26(int id0,double id1,double id2);
  public void InsertTuple2(int id0,double id1,double id2)
    { InsertTuple2_26(id0,id1,id2); }

  private native void InsertTuple3_27(int id0,double id1,double id2,double id3);
  public void InsertTuple3(int id0,double id1,double id2,double id3)
    { InsertTuple3_27(id0,id1,id2,id3); }

  private native void InsertTuple4_28(int id0,double id1,double id2,double id3,double id4);
  public void InsertTuple4(int id0,double id1,double id2,double id3,double id4)
    { InsertTuple4_28(id0,id1,id2,id3,id4); }

  private native void InsertTuple6_29(int id0,double id1,double id2,double id3,double id4,double id5,double id6);
  public void InsertTuple6(int id0,double id1,double id2,double id3,double id4,double id5,double id6)
    { InsertTuple6_29(id0,id1,id2,id3,id4,id5,id6); }

  private native void InsertTuple9_30(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9);
  public void InsertTuple9(int id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8,double id9)
    { InsertTuple9_30(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InsertNextTuple1_31(double id0);
  public void InsertNextTuple1(double id0)
    { InsertNextTuple1_31(id0); }

  private native void InsertNextTuple2_32(double id0,double id1);
  public void InsertNextTuple2(double id0,double id1)
    { InsertNextTuple2_32(id0,id1); }

  private native void InsertNextTuple3_33(double id0,double id1,double id2);
  public void InsertNextTuple3(double id0,double id1,double id2)
    { InsertNextTuple3_33(id0,id1,id2); }

  private native void InsertNextTuple4_34(double id0,double id1,double id2,double id3);
  public void InsertNextTuple4(double id0,double id1,double id2,double id3)
    { InsertNextTuple4_34(id0,id1,id2,id3); }

  private native void InsertNextTuple6_35(double id0,double id1,double id2,double id3,double id4,double id5);
  public void InsertNextTuple6(double id0,double id1,double id2,double id3,double id4,double id5)
    { InsertNextTuple6_35(id0,id1,id2,id3,id4,id5); }

  private native void InsertNextTuple9_36(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8);
  public void InsertNextTuple9(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7,double id8)
    { InsertNextTuple9_36(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void RemoveTuple_37(int id0);
  public void RemoveTuple(int id0)
    { RemoveTuple_37(id0); }

  private native void RemoveFirstTuple_38();
  public void RemoveFirstTuple()
    { RemoveFirstTuple_38(); }

  private native void RemoveLastTuple_39();
  public void RemoveLastTuple()
    { RemoveLastTuple_39(); }

  private native double GetComponent_40(int id0,int id1);
  public double GetComponent(int id0,int id1)
    { return GetComponent_40(id0,id1); }

  private native void SetComponent_41(int id0,int id1,double id2);
  public void SetComponent(int id0,int id1,double id2)
    { SetComponent_41(id0,id1,id2); }

  private native void InsertComponent_42(int id0,int id1,double id2);
  public void InsertComponent(int id0,int id1,double id2)
    { InsertComponent_42(id0,id1,id2); }

  private native void GetData_43(int id0,int id1,int id2,int id3,vtkDoubleArray id4);
  public void GetData(int id0,int id1,int id2,int id3,vtkDoubleArray id4)
    { GetData_43(id0,id1,id2,id3,id4); }

  private native void DeepCopy_44(vtkAbstractArray id0);
  public void DeepCopy(vtkAbstractArray id0)
    { DeepCopy_44(id0); }

  private native void DeepCopy_45(vtkDataArray id0);
  public void DeepCopy(vtkDataArray id0)
    { DeepCopy_45(id0); }

  private native void ShallowCopy_46(vtkDataArray id0);
  public void ShallowCopy(vtkDataArray id0)
    { ShallowCopy_46(id0); }

  private native void FillComponent_47(int id0,double id1);
  public void FillComponent(int id0,double id1)
    { FillComponent_47(id0,id1); }

  private native void Fill_48(double id0);
  public void Fill(double id0)
    { Fill_48(id0); }

  private native void CopyComponent_49(int id0,vtkDataArray id1,int id2);
  public void CopyComponent(int id0,vtkDataArray id1,int id2)
    { CopyComponent_49(id0,id1,id2); }

  private native int GetActualMemorySize_50();
  public int GetActualMemorySize()
    { return GetActualMemorySize_50(); }

  private native void CreateDefaultLookupTable_51();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_51(); }

  private native void SetLookupTable_52(vtkLookupTable id0);
  public void SetLookupTable(vtkLookupTable id0)
    { SetLookupTable_52(id0); }

  private native long GetLookupTable_53();
  public vtkLookupTable GetLookupTable() {
    long temp = GetLookupTable_53();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetRange_54(double id0[],int id1);
  public void GetRange(double id0[],int id1)
    { GetRange_54(id0,id1); }

  private native double[] GetRange_55(int id0);
  public double[] GetRange(int id0)
    { return GetRange_55(id0); }

  private native double[] GetRange_56();
  public double[] GetRange()
    { return GetRange_56(); }

  private native void GetRange_57(double id0[]);
  public void GetRange(double id0[])
    { GetRange_57(id0); }

  private native void GetFiniteRange_58(double id0[],int id1);
  public void GetFiniteRange(double id0[],int id1)
    { GetFiniteRange_58(id0,id1); }

  private native double[] GetFiniteRange_59(int id0);
  public double[] GetFiniteRange(int id0)
    { return GetFiniteRange_59(id0); }

  private native double[] GetFiniteRange_60();
  public double[] GetFiniteRange()
    { return GetFiniteRange_60(); }

  private native void GetFiniteRange_61(double id0[]);
  public void GetFiniteRange(double id0[])
    { GetFiniteRange_61(id0); }

  private native void GetDataTypeRange_62(double id0[]);
  public void GetDataTypeRange(double id0[])
    { GetDataTypeRange_62(id0); }

  private native double GetDataTypeMin_63();
  public double GetDataTypeMin()
    { return GetDataTypeMin_63(); }

  private native double GetDataTypeMax_64();
  public double GetDataTypeMax()
    { return GetDataTypeMax_64(); }

  private native void GetDataTypeRange_65(int id0,double id1[]);
  public void GetDataTypeRange(int id0,double id1[])
    { GetDataTypeRange_65(id0,id1); }

  private native double GetDataTypeMin_66(int id0);
  public double GetDataTypeMin(int id0)
    { return GetDataTypeMin_66(id0); }

  private native double GetDataTypeMax_67(int id0);
  public double GetDataTypeMax(int id0)
    { return GetDataTypeMax_67(id0); }

  private native double GetMaxNorm_68();
  public double GetMaxNorm()
    { return GetMaxNorm_68(); }

  private native long CreateDataArray_69(int id0);
  public vtkDataArray CreateDataArray(int id0) {
    long temp = CreateDataArray_69(id0);

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long COMPONENT_RANGE_70();
  public vtkInformationDoubleVectorKey COMPONENT_RANGE() {
    long temp = COMPONENT_RANGE_70();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long L2_NORM_RANGE_71();
  public vtkInformationDoubleVectorKey L2_NORM_RANGE() {
    long temp = L2_NORM_RANGE_71();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long L2_NORM_FINITE_RANGE_72();
  public vtkInformationDoubleVectorKey L2_NORM_FINITE_RANGE() {
    long temp = L2_NORM_FINITE_RANGE_72();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Modified_73();
  public void Modified()
    { Modified_73(); }

  private native long UNITS_LABEL_74();
  public vtkInformationStringKey UNITS_LABEL() {
    long temp = UNITS_LABEL_74();

    if (temp == 0) return null;
    return (vtkInformationStringKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CopyInformation_75(vtkInformation id0,int id1);
  public int CopyInformation(vtkInformation id0,int id1)
    { return CopyInformation_75(id0,id1); }

  private native int GetArrayType_76();
  public int GetArrayType()
    { return GetArrayType_76(); }

  public vtkDataArray() { super(); }

  public vtkDataArray(long id) { super(id); }

}
